#
# spec file for package perl-YAML-Syck
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-YAML-Syck
Version:        1.30
Release:        42.1
%define cpan_name YAML-Syck
Summary:        Fast, lightweight YAML loader and dumper
License:        MIT
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/YAML-Syck/
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module provides a Perl interface to the *libsyck* data serialization
library. It exports the 'Dump' and 'Load' functions for converting Perl
data structures to YAML strings, and the other way around.

*NOTE*: If you are working with other language's YAML/Syck bindings (such
as Ruby), please set '$YAML::Syck::ImplicitTyping' to '1' before calling
the 'Load'/'Dump' functions. The default setting is for preserving
backward-compatibility with 'YAML.pm'.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes COMPATIBILITY
%license COPYING

%changelog
* Fri Apr 21 2017 coolo@suse.com
- updated to 1.30
  see /usr/share/doc/packages/perl-YAML-Syck/Changes
* Wed Apr 15 2015 coolo@suse.com
- remove upstreamed 0001-Recognize-all-wide-unicode-characters.patch
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.29
  see /usr/share/doc/packages/perl-YAML-Syck/Changes
  [Changes for 1.29 - 2014-12-15]
  * Bump to 1.29 with no changes after CPAN Testers looks good.
  [Changes for 1.29_01 - 2014-12-14]
  * Experimentally try patch from RT 83825. Will release if no test failures or complaints.
  * Fix crash in syck_emit on platforms with long long pointers
  [Changes for 1.28 - 2014-12-11]
  * Bump to release version 1.28 for production release to CPAN
  [Changes for 1.28_01 - 2014-06-11]
  * Update inc modules to avoid precedence warnings in newer perl: RT 87034
* Wed Jun 26 2013 dvaleev@suse.com
- add 0001-Recognize-all-wide-unicode-characters.patch patch. Fixes
  test on PowerPC
* Fri Jun 14 2013 coolo@suse.com
- updated to 1.27
  * Resolve RT#84466 not fixed in 1.26 It failed about 10%% of the time.
  * Resolve RT#84882 and RT#84466 hash randomisation in yaml-alias.t on perl 5.18.0
  * Apply patch from RT 78363 - MinGW64 compatibility
  * Implement $JSON::Syck::MaxDepth
  * Prevent failure when the same object is seen twice during Dump.
  * Prevent YAML from being influnced by the previous
    change
  * Make sure that LoadBlessed=0 blocks all blessing.
  * Start listing primary repo as toddr on github ( http://github.com/toddr/YAML-Syck )
  * README refreshed via perldoc -t
  * Fix error message typo: s/existant/existent/g
  * Fix for non-printable character detection
  * Quote if non-printable characters are present
  * Change LoadBlessed=0 to not bless under ANY circumstances
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Nov  8 2011 pascal.bleser@opensuse.org
- update to 1.19: no user-visible changes
* Sun Nov  6 2011 pascal.bleser@opensuse.org
- update to 1.18:
  * perl RT#102606 - only lvalue subroutines are supposed to return the
    argument to "return" without copying it; stop relying on a pre-5.15 bug
  * break YAML::Syck dependency on Scalar::Util
* Thu Mar 31 2011 coolo@novell.com
- update to 1.17
  * Change a C99 comment to a C89 comment
  * Upgrade ppport.h from 3.13 to 3.19
  * Remove inc/Test/Builder/IO/Scalar.pm from MANIFEST
  * POD formatting fixes contributed by Justin Hunter
  * perl RT #78008 - The 5.13.5 development release of perl changed how
  regexes are stringified, breaking our tests. Update the tests to
  deal with the new syntax.
  See fb85c04 (http://perl5.git.perl.org/perl.git/commit/fb85c04) in
  perl.git for context.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Aug 30 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o obviously destructed
* Fri Aug 27 2010 pascal.bleser@opensuse.org
- update to 1.14:
  * RT RT60771 - quoted negative integer and quoted zeroes;
    this was breaking JSON since "0" is true in javascript
* Tue Aug 17 2010 chris@computersalat.de
- update to 1.12
  * The tie test proved to be very unstable for 5.8 and it's not
    relevant for tie actually. I'm converting it to a TODO for now.
- recreated by cpanspec 1.78
- added bcond_with opt
* Mon Jun  7 2010 lars@linux-schulserver.de
- update to 1.10:
  + fix installations on perl 5.8.3 and older (bumping
    Module::Install to 0.99 fixed it)
* Sun May 30 2010 lars@linux-schulserver.de
- update to 1.09:
  +  Reset the hash iterator after dumping hashes. Solves RT #54167
    and the duplicate RT #34166.
  + RT #39572: Only print 0.60 compatibility warning if 0.60 or
    earlier is installed.
* Tue May 25 2010 lars@linux-schulserver.de
- update to 1.08:
  + Include a WARNING section in the YAML::Syck pod that mentions that
    the module hasn't been actively maintained since 2007, and that
    perhaps prospective users might want to turn elsewhere.
  + Strings starting with : are now always quoted. Ruby will interpret
    anything starting with a colon as a symbol. Before this fix strings
    exported from YAML::Syck would be interpreted as Ruby symbols when
    read by Ruby's syck.
- Fix URL
* Sun Feb 21 2010 lars@linux-schulserver.de
- fix description
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 20 2009 chris@computersalat.de
- update to 1.07
  o Changes for 1.07 (JSON::Syck 0.30)
  * Added the missing Loadfile function to JSON::Syck.
    Reported by: Dan McCormick
  o Changes for 1.05 (JSON::Syck 0.29)
  * Loading a YAML stream containing Regexp nodes under -d:DProf should
    not fail with "panic: Devel::DProf inconsistent subroutine return".
    Reported by: Richard Jelinek
  o Changes for 1.04 (JSON::Syck 0.29)
  * The 'Name "YAML::Syck::ImplicitBinary" used only once: possible typo'
    warnings no longer triggers in Perl 5.10 when running with perl -w.
    Reported by: Jesse Vincent
  o Changes for 1.03 (JSON::Syck 0.29)
  * JSON::Syck: When $JSON::Syck::SingleQuote is false, implicit booleans
    such as "yes" and "no" should be dumped with double quotes, instead of
    single quotes (which breaks RFC 4627).
    Reported by: cho45
  o Changes for 1.02 (JSON::Syck 0.28)
  * JSON::Syck: Colons in single-quoted strings are no longer loaded
    with an extra space after it.
    Reported by: Agent Zhang
  o Changes for 1.01 (JSON::Syck 0.27)
  * JSON::XS is now promoted prominiently in JSON::Syck's documentation.
  * Added support for Perl 5.11 and its first-class Regexp objects.
    Contributed by: Andreas Koenig
  * Tests no longer fail incorrectly when JSON.pm 2.00+ is installed.
    Contributed by: Andreas Koenig
  * Removed the unused Syck bytecode modules (yamlbyte.h and yaml2byte.c)
    to further reduce our memory footprint.
  o Changes for 1.00 (JSON::Syck 0.26)
  * When $YAML::Syck::SingleQuote is set to true, Dump() now emits newlines
    in strings correctly.  (Previously it would emit extra newlines.)
  o Changes for 0.99 (JSON::Syck 0.26)
  * TODOify tests as appropriate for Perl 5.005 and Perl 5.6.x.
  o Changes for 0.98 (JSON::Syck 0.26)
  * Restore support for Perl 5.005 and earlier.
  o Changes for 0.97 (JSON::Syck 0.26)
  * When loading !!perl/code with $YAML::Syck::LoadCode set to false,
    YAML::Syck now returns a coderef that does nothing (i.e. sub {}),
    in accordance with YAML.pm's treatment, instead of returning the
    actual code of the sub as a string.
    Contributed by: Florian Ragwitz
  o Changes for 0.96 (JSON::Syck 0.26)
  * The always-quote rule now applies to all implicit booleans
    and null values, i.e. strings that match the following regex:
    /y|Y
    |n|N
    |yes|Yes|YES
    |no|No|NO
    |true|True|TRUE
    |false|False|FALSE
    |on|On|ON
    |off|Off|OFF
    |null|Null|NULL
    |~
    /x
  * Bare literals "Y", "N", "y" and "n" are now recognized as
    booleans when loading with implicit typing turned on.
  * Mixed case strings that does not represent implicit boolean
    values, such as "yES" and "nO", are no longer always-quoted.
    Contributed by: Malcolm Studd
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Mon Aug  6 2007 mrueckert@suse.de
- initial package of version 0.95
  (based on the buildservice package from dmacvicar)
